TrendIndicatorChart class

Inheritance

Constructors

TrendIndicatorChart({required String label, required double currentValue, required String trend, required String trendDetails, ChartThemeData? themeData})

Properties

color Color?
finalinherited
currentValue double
final
enableTooltip bool
finalinherited
fontSize double?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String
finalinherited
margin EdgeInsets?
finalinherited
onTap VoidCallback?
finalinherited
padding EdgeInsets?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
finalinherited
themeData ChartThemeData?
final
tooltipSettings TooltipSettings
finalinherited
trend String
final
trendDetails String
final
unit String
finalinherited
value → dynamic
finalinherited

Methods

buildChart() Widget
override
buildTooltip(BuildContext context, Offset globalPosition) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateData() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited