TextualStatusChart class

Inheritance

Constructors

TextualStatusChart({required String label, required String status, String unit = '', ChartThemeData? themeData, Color statusColor = Colors.green})

Properties

color Color?
finalinherited
enableTooltip bool
finalinherited
fontSize double?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String
finalinherited
margin EdgeInsets?
finalinherited
onTap VoidCallback?
finalinherited
padding EdgeInsets?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
finalinherited
status String
final
statusColor Color
final
themeData ChartThemeData?
final
tooltipSettings TooltipSettings
finalinherited
unit String
finalinherited
value → dynamic
finalinherited

Methods

buildChart() Widget
override
buildTooltip(BuildContext context, Offset globalPosition) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateData() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited